@@ -6,18 +6,18 @@ test_that("Test function createTanimotoBaseline()", {
   atchashda <-
     readAtcMapIntoHashMapDrugNamesAtcCodes(
       system.file("extdata", "db-atc.map", package = "epos"), "\t")
-  tepso <- genDictListFromRawFreq(rawDrugBankCoOcEpSO[1:500])
+  tepso <- genDictListFromRawFreq(rawDrugBankCoOcEpSO)
   neuroepso <- filterNeuroDrugs(tepso, atchashda)
   utils::data(rawDrugBankCoOcESSO, package="epos")
-  tesso <- genDictListFromRawFreq(rawDrugBankCoOcESSO[1:500])
+  tesso <- genDictListFromRawFreq(rawDrugBankCoOcESSO)
   neuroesso <- filterNeuroDrugs(tesso, atchashda)
   utils::data(rawDrugBankCoOcEPILONT, package="epos")
-  tepi <- genDictListFromRawFreq(rawDrugBankCoOcEPILONT[1:500])
+  tepi <- genDictListFromRawFreq(rawDrugBankCoOcEPILONT)
   neuroepi <- filterNeuroDrugs(tepi, atchashda)
   dneuro <-
-    data.frame(EpSO = neuroepso[1:10],
-               ESSO = neuroesso[1:10],
-               EPILONT = neuroepi[1:10])
+    data.frame(EpSO = neuroepso[1:210],
+               ESSO = neuroesso[1:210],
+               EPILONT = neuroepi[1:210])
   dneuromaxk <- TopKLists::calculate.maxK(dneuro, 3, 5, 10)
   tanimotobaseline <- createTanimotoBaseline(neuroepso, neuroesso, neuroepi, dneuromaxk)
   expect_that(length(tanimotobaseline), equals(9))
