@@ -5,5 +5,5 @@ test_that("Test function readAtcMapIntoHashMapAtcCodesAtcNames()", {
   atchashaa <-
      readAtcMapIntoHashMapAtcCodesAtcNames(
        system.file("extdata", "db-atc.map", package = "epos"), "\t")
-  expect_that(length(atchashaa$keys()), equals(619))
+  expect_that(length(names(atchashaa)), equals(619))
 })
\ No newline at end of file
