@@ -4,5 +4,5 @@ context("test_readAtcMapIntoHashMapDrugNamesAtcCodes")
 test_that("Test function readAtcMapIntoHashMapDrugNamesAtcCodes()", {
   atchashda <- readAtcMapIntoHashMapDrugNamesAtcCodes(
     system.file("extdata", "db-atc.map", package = "epos"), "\t")
-  expect_that(length(atchashda$keys()), equals(2286))
+  expect_that(length(names(atchashda)), equals(2286))
 })
\ No newline at end of file
