@@ -5,5 +5,5 @@ test_that("Test function readSecondLevelATC()", {
   atchashsec <-
     readSecondLevelATC(
     system.file("extdata", "drugbankatc-secondlevel.map", package = "epos"), "\t")
-  expect_that(length(atchashsec$keys()), equals(89))
+  expect_that(length(names(atchashsec)), equals(89))
 })
\ No newline at end of file
